
Credits
=======

Development Lead
----------------

* Ag Stephens <ag.stephens@stfc.ac.uk> `@agstephens <https://github.com/agstephens>`_

Co-Developers
-------------

* Carsten Ehbrecht <ehbrecht@dkrz.de> `@cehbrecht <https://github.com/cehbrecht>`_
* Eleanor Smith <eleanor.smith@stfc.ac.uk> `@ellesmith88 <https://github.com/ellesmith88>`_
* Martin Schupfner <schupfner@dkrz.de> `@sol1105 <https://github.com/sol1105>`_
* Pascal Bourgault <bourgault.pascal@ouranos.ca> `@aulemahal <https://github.com/aulemahal>`_
* Trevor James Smith <smith.trevorj@ouranos.ca> `@Zeitsperre <https://github.com/Zeitsperre>`_

Contributors
------------

* Charles Gauthier <gauthier.charles@ouranos.ca> `@charlesgauthier-udm <https://github.com/charlesgauthier-udm>`_
* David Huard <huard.david@ouranos.ca> `@huard <https://github.com/huard>`_
* Gabriel Rondeau-Genesse <rondeau-genesse.gabriel@ouranos.ca> `@RondeauG <https://github.com/RondeauG>`_
* Marco Braun <Braun.Marco@ouranos.ca> `@vindelico <https://github.com/vindelico>`_
* Travis Logan <logan.travis@ouranos.ca> `@tlogan2000 <https://github.com/tlogan2000>`_
* Juliette Lavoie <lavoie.juliette@ouranos.ca> `@juliettelavoie <https://github.com/juliettelavoie>`_
